@@ -185,6 +185,8 @@ migemo* gMigemo;
 
 void migemo_init()
 {
+    setenv("COMPLETION_ENABLE_MIGEMO", 1, 1);
+
     char buf[PATH_MAX];
     char migemodir[PATH_MAX];
     gMigemo = migemo_open(NULL);
@@ -343,7 +345,7 @@ char* readline_file_completion_migemo_match(char* text, char* file, regex_t* reg
         migemo_release(gMigemo, (unsigned char*) p);
 
         if(r != ONIG_NORMAL) {
-            if(strlen(p2) > 2) { puts("AAA"); onig_free(reg); }
+            if(strlen(p2) > 2) { onig_free(reg); }
 
             FREE(p2);
             return NULL;
@@ -493,6 +495,9 @@ char* readline_file_completion_migemo(const char* text, int rstat)
             string_push_back(gEditingDir2, p);
 
             string_put(gEditingDir, string_c_str(gEditingDir2));
+
+            string_delete(gEditingDir2);
+            string_delete(user);
         }
 
         /// 補完候補を初期化 ///
@@ -833,6 +838,13 @@ char* readline_user_completion(const char* text, int stat)
         sRFd_delete(pipein);
     }
 
+    char* returned_variable = saphire_get_global_var("COMPLETION_ADD_SPACE");
+    if(returned_variable && strcmp(returned_variable, "0") == 0) {
+        rl_completion_append_character= 0;
+    } else {
+        rl_completion_append_character= 1;
+    }
+
     while(index < vector_size(gUserCompletions)) {
         char* ucomp = string_c_str(vector_item(gUserCompletions, index));
         index++;
@@ -1249,9 +1261,9 @@ char** readline_on_complete(const char* text, int start, int end)
             if(program) { string_push_back2(command, *p); }
             string_push_back2(statment, *p);
             p++;
-            program = FALSE;
-            user = FALSE;
             ref = TRUE;
+            //program = FALSE;
+            user = FALSE;
             method = FALSE;
             file = FALSE;
         }
@@ -1270,16 +1282,8 @@ char** readline_on_complete(const char* text, int start, int end)
         }
         /// メソッド
         else if(*p == '-' && *(p+1) == '>') {
-            string_push_back2(buf, *p);
-            if(program) { string_push_back2(command, *p); }
-            string_push_back2(statment, *p);
-            p++;
-            string_push_back2(buf, *p);
-            if(program) { string_push_back2(command, *p); }
-            string_push_back2(statment, *p);
-            p++;
-
-            if(program) {
+            p+=2;
+            if(program) { 
                 sObject* object;
                 if(string_c_str(buf)[0] == '$') {
                     sRef* ref = saphire_get_ref(string_c_str(buf) + 1);
@@ -1304,15 +1308,16 @@ char** readline_on_complete(const char* text, int start, int end)
                         vector_delete(gMethodCompletions);
                     }
                     gMethodCompletions = saphire_methods_names(object);
-                    program = FALSE;
-                    user = FALSE;
-                    ref = FALSE;
                     method = TRUE; 
-                    file = FALSE;
+                    program = FALSE;  
                 }
                 string_put(buf, "");
             }
+
+            user = FALSE;
+            ref = FALSE;
         }
+
         /// リダイレクト
         else if(*p == '<' || *p == '>' || *p == '%') {
             if(program) { string_push_back2(command, *p); }
@@ -1424,6 +1429,13 @@ char** readline_on_complete(const char* text, int start, int end)
             string_put(command, "");
             string_put(statment, "");
         }
+        else if(*p == '/') {
+            user = FALSE;
+            string_push_back2(buf, *p);
+            if(program) { string_push_back2(command, *p); }
+            string_push_back2(statment, *p);
+            p++;
+        }
         /// 終了 ///
         else if(*p == 0) {
             break;
