@@ -66,6 +66,7 @@ typedef struct _sClass {
     sStatments* statments; // 命令表
     struct _sClass* parent;        // オーバーライド先
     BOOL input;             // 実行時の情報
+    BOOL output;
 
     int mRefCount;
 } sClass;
@@ -186,7 +187,9 @@ BOOL sRFd_close(sRFd* self);
 int sRFd_read_all(sRFd* self, string_obj* str);
 int sRFd_read_all_preserve(sRFd* self, string_obj* str);
 int sRFd_read_oneline(sRFd* self, string_obj* str, enum eLineField lf);
+int sRFd_read_oneline_num(sRFd* self, string_obj* str, int line_num, enum eLineField lf);
 int sRFd_read_oneline_preserve(sRFd* self, string_obj* str, enum eLineField lf);
+int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num, enum eLineField lf);
 int sRFd_read_all_to_buffer(sRFd* self);
 void sRFd_set_buffer(sRFd* self, char* buffer);
 
@@ -436,6 +439,9 @@ typedef struct {
 
 void err_msg(char* msg, char* sname, int line);
     // エラーメッセージを設定
+ 
+extern BOOL gRunningOnTerminal;
+    // 端末上で動いているかどうか
 
 #endif
 
