@@ -62,6 +62,9 @@ enum eCommandKind {
     kTime,
     kFSelector,
     kCommandHistory,
+    kUnset,
+    kUMask,
+    kErrMsg,
     kInnerCommand,
     kCommand 
 };
@@ -386,6 +389,7 @@ typedef struct _sFunction {
     //vector_obj* args;       // ե󥹤ΰ
     sStatments* statments; // ̿ɽ
     BOOL input;             // ¹Իξ
+    BOOL output;
 
     struct _sFunction* parent;     // С饤ɤȤο
 
