@@ -93,7 +93,7 @@ static BOOL read_until_next_close_character(char first_char, char last_char, cha
             }
             else if(squote || dquote) {
                 if(**p == 0) {
-                    err_msg("require ' or \" before the end of source", sname, *sline);
+                    err_msg("close ' or \" before the end of source", sname, *sline);
                     return FALSE;
                 }
                 else {
@@ -121,7 +121,7 @@ static BOOL read_until_next_close_character(char first_char, char last_char, cha
             }
             else if(**p == 0) {
                 char buf[256];
-                snprintf(buf, 256, "read_util_next_close_character: unexpected end(0). need last char(%c)", last_char);
+                snprintf(buf, 256, "read_util_next_close_character: unexpected end(0). close with (%c)", last_char);
                 err_msg(buf, sname, *sline);
                 return FALSE;
             }
@@ -265,7 +265,7 @@ static BOOL read_block(char** p, string_obj* contents, vector_obj* args, string_
         /// シングルクォート、ダブルクォート中 ///
         else if(squote || dquote) {
             if(**p == 0) {
-                err_msg("get block: require \" or \'", sname, line_of_head);
+                err_msg("get block: close \" or \' before the end of block", sname, line_of_head);
                 return FALSE;
             }
             else if(line_inc && **p == '\n') {
@@ -293,7 +293,7 @@ static BOOL read_block(char** p, string_obj* contents, vector_obj* args, string_
             }
         }
         else if(**p == 0) {
-            err_msg("get block: found 0. require }", sname, line_of_head);
+            err_msg("get block: found 0. close }", sname, line_of_head);
             return FALSE;
         }
         else if(**p == '\n') {
@@ -1859,7 +1859,7 @@ BOOL expand_env(char* p, string_obj* out, sRFd* rfd, char* sname, int* sline, sO
         }
         else if(squote || dquote) {
             if(*p == 0) {
-                err_msg("require ' or \"", sname, *sline);
+                err_msg("close ' or \" before the end of statment", sname, *sline);
                 return FALSE;
             }
 
@@ -1913,7 +1913,7 @@ BOOL delete_comments(char* p, string_obj* cmdline2, char* separator, char* sname
         }
         else if(squote || dquote) {
             if(*p == 0) {
-                err_msg("require \" or \'", sname, *sline);
+                err_msg("close \" or \' before the end of comments", sname, *sline);
                 return FALSE;
             }
             else {
